@@ -10,7 +10,7 @@ from tcms.rpc.decorators import permissions_required
 @rpc_method(name='Priority.filter')
 def filter(query):  # pylint: disable=redefined-builtin
     """
-    .. function:: XML-RPC Priority.filter(query)
+    .. function:: RPC Priority.filter(query)
 
         Perform a search and return the resulting list of priorities.
 
